package development

import (
	"strings"

	"shylinux.com/x/ice"
	"shylinux.com/x/icebergs/base/cli"
	"shylinux.com/x/icebergs/base/ctx"
	"shylinux.com/x/icebergs/base/mdb"
	"shylinux.com/x/icebergs/base/nfs"
	"shylinux.com/x/icebergs/base/web"
	"shylinux.com/x/icebergs/core/code"
	kit "shylinux.com/x/toolkits"

	"shylinux.com/x/operation/src/development/model"
)

type serve struct {
	Tables
	repos   repos
	order   string `data:"1"`
	imports string `name:"imports" role:"leader,worker"`
	autogen string `name:"autogen name* help* class* table*" icon:"bi bi-plus-square-dotted" role:"leader,worker"`
}

func (s serve) BeforeAction(m *ice.Message, arg ...string) *ice.Message {
	msg := m.Cmd(s.repos, s.Select, model.UID, m.Option(model.REPOS_UID), ice.Maps{mdb.TABLE: ""})
	m.Option(model.REPOS_NAME, msg.Append(model.NAME))
	return msg
}
func (s serve) Imports(m *ice.Message, arg ...string) {
	s.spaceCmdy(m, web.CODE_GIT_REPOS, "init", kit.MergeURL2(m.Option(ice.MSG_USERHOST), "/x/"+m.Option(model.REPOS_NAME)))
	s.spaceCmdy(m, web.CODE_AUTOGEN, code.IMPORT, "gonganxitong", "shylinux.com/x/community")
	s.spaceCmdy(m, web.CODE_AUTOGEN, code.IMPORT, "db/mysql", "shylinux.com/x/mysql-story")
	s.spaceCmdy(m, web.CODE_VIMER, code.COMPILE)
	s.SpaceCmdy(m, ice.OPS, web.CODE_COMPILE, code.DEVPACK)
	m.Sleep("3s")
}
func (s serve) Autogen(m *ice.Message, arg ...string) {
	s.spaceCmdy(m, "web.team.gonganxitong.service", code.AUTOGEN, arg)
	s.spaceCmdy(m, cli.SYSTEM, "git", "add", "src")
	s.spaceCmdy(m, cli.SYSTEM, "git", "commit", "-am", "add some")
	s.spaceCmdy(m, cli.SYSTEM, "git", "push")
	s.spaceCmdy(m, web.CODE_VIMER, code.COMPILE)
}
func (s serve) List(m *ice.Message, arg ...string) {
	msg := s.BeforeAction(m.Options(model.REPOS_UID, arg[0]))
	switch ReposType(kit.Int(msg.Append(model.TYPE))) {
	case ReposSystem:
		if s.spaceCmd(m, ctx.COMMAND, "web.team.gonganxitong.portal").Length() == 0 {
			s.Button(m, "", s.Imports)
			return
		}
		s.spaceCmd(m, nfs.DIR, nfs.SRC, nfs.PATH, nfs.SIZE, kit.Dict(
			nfs.DIR_DEEP, ice.TRUE, nfs.DIR_TYPE, nfs.TYPE_CAT, nfs.DIR_REG, "portal.go",
		)).Table(func(value ice.Maps) {
			m.Push(model.NAME, strings.Split(value[nfs.PATH], "/")[1])
		})
		m.PushAction(s.Open, s.Config).Action(s.Autogen).Display("")
		s.Button(m, "", s.Autogen)
	}
}
func (s serve) Open(m *ice.Message, arg ...string) {
	m.ProcessOpen(web.S(m.Option(model.REPOS_NAME)) + web.C("web.team."+m.Option(model.NAME)+".portal"))
}
func (s serve) Config(m *ice.Message, arg ...string) {
	m.ProcessOpen(web.S(m.Option(model.REPOS_NAME)) + web.C("web.team."+m.Option(model.NAME)+".portal") + "?view=table")
}

func init() { ice.TeamCtxCmd(serve{}) }

func (s serve) spaceCmdy(m *ice.Message, arg ...ice.Any) *ice.Message {
	return s.SpaceCmdy(m, m.Option(model.REPOS_NAME), arg...)
}
func (s serve) spaceCmd(m *ice.Message, arg ...ice.Any) *ice.Message {
	return s.SpaceCmd(m, m.Option(model.REPOS_NAME), arg...)
}
